pub struct Quaternion {
pub x: f32,
pub y: f32,
pub z: f32,
pub w: f32,
}Expand description
Unit quaternion used for 3D rotation interpolation.
The components are stored as (x, y, z, w). Interpolate uses
shortest-path spherical linear interpolation.
Fields
x: f32X component of the vector part.
y: f32Y component of the vector part.
z: f32Z component of the vector part.
w: f32Scalar part.
Implementations
Sourceimpl Quaternion
impl Quaternion
Sourcepub const IDENTITY: Quaternion
pub const IDENTITY: Quaternion
Identity rotation.
Sourcepub fn from_axis_angle(axis: [f32; 3], angle: Angle) -> Quaternion
pub fn from_axis_angle(axis: [f32; 3], angle: Angle) -> Quaternion
Create a quaternion from an axis and angle in degrees.
Sourcepub fn dot(self, other: Quaternion) -> f32
pub fn dot(self, other: Quaternion) -> f32
Dot product between two quaternions.
Sourcepub fn normalized(self) -> Quaternion
pub fn normalized(self) -> Quaternion
Return a normalized quaternion, or identity when length is invalid.
Sourcepub fn negated(self) -> Quaternion
pub fn negated(self) -> Quaternion
Return the negated representation of the same rotation.
Sourcepub fn slerp(self, other: Quaternion, t: f32) -> Quaternion
pub fn slerp(self, other: Quaternion, t: f32) -> Quaternion
Spherical linear interpolation using the shortest rotation path.