pub struct KeyframeTrack<T>where
T: Animatable,{
pub looping: Loop,
/* private fields */
}Expand description
A sorted collection of keyframes that evaluates a value over time.
Empty tracks are valid. They evaluate to None instead of requiring
T: Default or panicking.
Example
use animato_core::{Easing, Update};
use animato_tween::KeyframeTrack;
let mut track = KeyframeTrack::new()
.push_eased(0.0, 0.0_f32, Easing::EaseOutCubic)
.push(1.0, 100.0);
track.update(0.5);
assert!(track.value().unwrap() > 50.0);Fields
looping: LoopLooping behavior for this track.
Implementations
Sourceimpl<T> KeyframeTrack<T>where
T: Animatable,
impl<T> KeyframeTrack<T>where
T: Animatable,
Sourcepub fn new() -> KeyframeTrack<T>
pub fn new() -> KeyframeTrack<T>
Create an empty keyframe track.
Sourcepub fn push(self, time: f32, value: T) -> KeyframeTrack<T>
pub fn push(self, time: f32, value: T) -> KeyframeTrack<T>
Insert a linear keyframe and keep the track sorted by time.
If another frame already exists at the same time, it is replaced.
Sourcepub fn push_eased(self, time: f32, value: T, easing: Easing) -> KeyframeTrack<T>
pub fn push_eased(self, time: f32, value: T, easing: Easing) -> KeyframeTrack<T>
Insert a keyframe with an explicit segment easing.
If another frame already exists at the same time, it is replaced.
Sourcepub fn looping(self, mode: Loop) -> KeyframeTrack<T>
pub fn looping(self, mode: Loop) -> KeyframeTrack<T>
Set the looping behavior.
Sourcepub fn value_at(&self, secs: f32) -> Option<T>
pub fn value_at(&self, secs: f32) -> Option<T>
Evaluate the track at an absolute time in seconds.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
true when the track has finished all finite playback.